==> fincept-investments-0.1.1.tar.gz: fincept-investments-0.1.1/README.md <==
# Fincept Investments ✨

[![License: MIT](https://img.shields.io/badge/license-MIT-C06524)](https://github.com/yourusername/fincept-investments/blob/main/LICENSE.txt)
[![PyPI - Version](https://img.shields.io/pypi/v/fincept-investments.svg)](https://pypi.org/project/fincept-investments/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/fincept-investments.svg)](https://pypi.org/project/fincept-investments/)
[![Downloads](https://static.pepy.tech/badge/fincept-investments/month)](https://pypi.org/project/fincept-investments/)

**Fincept Investments** is a comprehensive CLI tool that provides financial insights, market analysis, and a host of other financial services such as technical analysis, fundamental analysis, sentiment analysis, quantitative analysis, and economic data services. It's designed to help investors and financial professionals navigate the complex world of investments with ease and precision.

(Currently it has more India Specific Data we are constantly updating it for presenting world data and new updates are release everyday. If you are from another country and can help me with the data source of your country please reach out to me.)

## Features 🧐

- **Market Tracker**: Track FII/DII data, Nifty 50 list, and more.
- **Economics**: Get economic indicators and analysis (Feature under development).
- **News**: Stay updated with top financial news across the globe.
- **Technical Analysis**: Perform technical analysis on stocks and market indices.
- **Fundamental Analysis**: Dive deep into the fundamentals of companies.
- **Sentiment Analysis**: Gauge market sentiment with real-time data.
- **Quantitative Analysis**: Analyze financial data using quantitative methods.
- **Economic Data**: Access key economic indicators to inform your investment decisions.

## Installation 🚀

Install the latest version of Fincept Investments from PyPI: pip install fincept-investments 

## USAGE

1 -> Stock Tracker -> fiidii Data , stock query
2 -> Economics (InDevelopment)
3 -> News -> 10 Country News Available

```toml
fincept start
```

## UPCOMING FEATURS

- **World Mariane Trade Data**
- **India Bond Data**
- **India Mutual Fund Data**
- **Company Finaical Statements Data**

## PLEASE LEAVE AN STAR ON THE REPO AND FOR ANY QUERY OR UPDATE REACH OUT TO ME ON dev@fincept.in

==> fincept-investments-0.1.2.tar.gz: fincept-investments-0.1.2/README.md <==
# Fincept Investments ✨

[![License: MIT](https://img.shields.io/badge/license-MIT-C06524)](https://github.com/yourusername/fincept-investments/blob/main/LICENSE.txt)
[![PyPI - Version](https://img.shields.io/pypi/v/fincept-investments.svg)](https://pypi.org/project/fincept-investments/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/fincept-investments.svg)](https://pypi.org/project/fincept-investments/)
[![Downloads](https://static.pepy.tech/badge/fincept-investments/month)](https://pypi.org/project/fincept-investments/)

**Fincept Investments** is a comprehensive CLI tool that provides financial insights, market analysis, and a host of other financial services such as technical analysis, fundamental analysis, sentiment analysis, quantitative analysis, and economic data services. It's designed to help investors and financial professionals navigate the complex world of investments with ease and precision.

(Currently, it has more India-specific data. We are constantly updating it to present world data, and new updates are released every day. If you are from another country and can help me with the data source of your country, please reach out to me.)

## Features 🧐

- **Market Tracker**: Track FII/DII data, Nifty 50 list, and more.
- **Economics**: Get economic indicators and analysis (Feature under development).
- **News**: Stay updated with top financial news across the globe.
- **Technical Analysis**: Perform technical analysis on stocks and market indices.
- **Fundamental Analysis**: Dive deep into the fundamentals of companies.
- **Sentiment Analysis**: Gauge market sentiment with real-time data.
- **Quantitative Analysis**: Analyze financial data using quantitative methods.
- **Economic Data**: Access key economic indicators to inform your investment decisions.

## Installation 🚀

Install the latest version of Fincept Investments from PyPI: pip install fincept-investments 

## USAGE

1 -> Stock Tracker -> fiidii Data , stock query
2 -> Economics (InDevelopment)
3 -> News -> 10 Country News Available

```toml
fincept start
```

## UPCOMING FEATURS

- **World Mariane Trade Data**
- **India Bond Data**
- **India Mutual Fund Data**
- **Company Finaical Statements Data**

## Star History

![GitHub repo stats](https://github-readme-stats.vercel.app/api/pin/?username=Fincept-Corporation&repo=FinceptTerminal&show_icons=true&theme=radical)
[![Star History Chart](https://api.star-history.com/svg?repos=Fincept-Corporation/fincept-investments&type=Date)](https://star-history.com/#Fincept-Corporation/fincept-investments&Date)


## PLEASE LEAVE AN STAR ON THE REPO AND FOR ANY QUERY OR UPDATE REACH OUT TO ME ON dev@fincept.in
